Index: uspace/lib/usbvirt/main.c
===================================================================
--- uspace/lib/usbvirt/main.c	(revision bbe78485cd8633d7413573caf386c2dc4d185762)
+++ uspace/lib/usbvirt/main.c	(revision 11feca82b4a9309b6e35b39b70650e7db5fbebba)
@@ -183,7 +183,7 @@
 }
 
-/** Create necessary phones for comunication with virtual HCD.
+/** Create necessary phones for communication with virtual HCD.
  * This function wraps following calls:
  * -# open <code>/dev/devices/\\vhc for reading
  * -# access phone of file opened in previous step
  * -# create callback through just opened phone
@@ -193,8 +193,6 @@
  * @warning This function is wrapper for several actions and therefore
  * it is not possible - in case of error - to determine at which point
- * error occured.
- *
- * @param hcd_path HCD identification under devfs
- *     (without <code>/dev/usb/</code>).
+ * error occurred.
+ *
  * @param dev Device to connect.
  * @return EOK on success or error code from errno.h.
@@ -207,5 +205,5 @@
 	}
 	
-	const char *vhc_path = "/vhc";
+	const char *vhc_path = "/virt/usbhc";
 	int rc;
 	devman_handle_t handle;
@@ -183,7 +183,7 @@
  * This function wraps following calls:
- * -# open <code>/dev/devices/\\vhc for reading
+ * -# open <code>/dev/devices/\\virt\\usbhc for reading
  * -# access phone of file opened in previous step
  * -# create callback through just opened phone
